bbprep
======

.. automodule:: bbprep

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: class.rst
      :nosignatures:
   
      ClosestFGs
      Conformer
      DitopicFitter
      Ensemble
      FurthestFGs
      MinimiseAngle
      Modifier
      PanelBuildingBlock
      Planarfy
      Process
      RandomFGs
      ReorientC1Panel
      ReorientC2Panel
      ReorientPanel
      TargetProcess
      TargetTorsion
   
   

   
   
   



.. rubric:: Modules

.. autosummary::
   :toctree:
   :template: module.rst
   :recursive:

   bbprep.generators
   bbprep.selectors

